flutter_animate_counter library
A Flutter widget that animates numeric value changes with a smooth counting transition.
Classes
- CurrencyPreset
-
A single currency ready to hand to FlutterAnimateCounter's
currencyandlocaleparameters. - CurrencyPresets
-
A static, reusable list of common world currencies for use with
FlutterAnimateCounter's
currencyandlocaleparameters — handy for building a currency picker without hand-rolling the code/locale pairs. - FlutterAnimateCounter
- Displays value and animates to any new value it is given, counting up or down between the old and new number.